@@ -1,8 +1,5 @@
 #!/usr/bin/perl -w
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
 use Data::Stag qw(:all);
 use Data::Stag::ITextParser;
 use Data::Stag::Simple;
@@ -15,3 +12,18 @@ foreach my $f (@ARGV) {
     $p->parse($f);
 }
 
+__END__
+
+=head1 NAME
+
+stag-itext2simple - converts between stag formats
+
+=head1 DESCRIPTION
+
+Converts from itext to simple format.
+
+=head1 SEE ALSO
+
+L<Data::Stag>
+
+=cut
