@@ -1,8 +1,5 @@
 #!/usr/bin/perl -w
 
-eval 'exec /usr/bin/perl -w -S $0 ${1+"$@"}'
-    if 0; # not running under some shell
-
 use Data::Stag qw(:all);
 use Data::Stag::XMLParser;
 use Data::Stag::ITextWriter;
@@ -12,4 +9,19 @@ $p->handler($h);
 foreach my $xmlfile (@ARGV) {
     $p->parse($xmlfile);
 }
+__END__
+
+=head1 NAME
+
+stag-xml2itext - converts between stag formats
+
+=head1 DESCRIPTION
+
+Converts from xml to itext format.
+
+=head1 SEE ALSO
+
+L<Data::Stag>
+
+=cut
 
