@@ -2,7 +2,7 @@ package Data::Stag::ITextWriter;
 
 =head1 NAME
 
-  Data::Stag::ITextWriter
+  Data::Stag::ITextWriter - writes stag events into stag IText format
 
 =head1 SYNOPSIS
 
@@ -19,7 +19,7 @@ use strict;
 use base qw(Data::Stag::Writer);
 
 use vars qw($VERSION);
-$VERSION="0.11";
+$VERSION="0.14";
 
 sub fmtstr {
     return 'itext';
